import requests
import json
import os
from urllib.parse import urlencode

config = dict()
config['pushover_api_url'] = os.environ['PUSHOVER_API_URL'] if 'PUSHOVER_API_URL' in os.environ else 'https://api.pushover.net/1/messages.json'
config['pushover_token'] = os.environ['PUSHOVER_TOKEN'] if 'PUSHOVER_TOKEN' in os.environ else 'dummy'
config['pushover_user'] = os.environ['PUSHOVER_USER'] if 'PUSHOVER_USER' in os.environ else 'dummy'

def send(message):
	post_form = urlencode({
		"token": config['pushover_token'],
		"user": config['pushover_user'],
		"message": message
	})
	try:
		response = requests.post(config['pushover_api_url'], headers={'Content-type': 'application/x-www-form-urlencoded'}, data=post_form)
		if response.status_code == 200:
			response_json = json.loads(response.text)
			if 'status' not in response_json or response_json['status'] != 1:
				print("Attempt at sending Pushover message has failed:")
				print(response_json)
		else:
			print("Pushover API has returned http response code %d" % response.status_code)
	except Exception as e:
		print("Pushover API request has failed with exception: %s" % str(e))
